Avoid divisive terms (#2523)

diff --git a/lib/src/utils.dart b/lib/src/utils.dart
index c1e92b6..184bcf5 100644
--- a/lib/src/utils.dart
+++ b/lib/src/utils.dart
@@ -257,7 +257,7 @@
   }).toSet();
 }
 
-/// Given a denylist of directory names, returns a set of patterns that can
+/// Given a of unwanted directory names, returns a set of patterns that can
 /// be used to filter for those directory names.
 ///
 /// For a given path, that path contains some string in the returned set if
diff --git a/test/package_list_files_test.dart b/test/package_list_files_test.dart
index 2d08108..3871ba0 100644
--- a/test/package_list_files_test.dart
+++ b/test/package_list_files_test.dart
@@ -265,7 +265,7 @@
           ]));
     });
 
-    test("doesn't care if the root is blacklisted", () async {
+    test("doesn't care if the root is disallowed", () async {
       await d.dir(appPath, [
         d.file('file1.txt', 'contents'),
         d.file('file2.txt', 'contents'),
diff --git a/lib/src/io.dart b/lib/src/io.dart
index 71a320d..9864049 100644
--- a/lib/src/io.dart
+++ b/lib/src/io.dart
@@ -239,7 +239,7 @@
 /// `.` (defaults to `false`). If [includeDirs] is `true`, includes directories
 /// as well as files (defaults to `true`).
 ///
 /// [whiteList] is a list of hidden filenames to include even when
 /// [includeHidden] is `false`.
 ///
 /// Note that dart:io handles recursive symlinks in an unfortunate way. You
@@ -254,9 +254,9 @@
     {bool recursive = false,
     bool includeHidden = false,
     bool includeDirs = true,
-    Iterable<String> whitelist}) {
-  whitelist ??= [];
-  var whitelistFilter = createFileFilter(whitelist);
+    Iterable<String> allowed}) {
+  allowed ??= [];
+  var allowlistFilter = createFileFilter(allowed);
 
   // This is used in some performance-sensitive paths and can list many, many
   // files. As such, it leans more heavily towards optimization as opposed to
@@ -283,13 +283,13 @@
         assert(entity.path.startsWith(dir));
         var pathInDir = entity.path.substring(dir.length);
 
-        // If the basename is whitelisted, don't count its "/." as making the file
-        // hidden.
-        var whitelistedBasename =
-            whitelistFilter.firstWhere(pathInDir.contains, orElse: () => null);
-        if (whitelistedBasename != null) {
-          pathInDir = pathInDir.substring(
-              0, pathInDir.length - whitelistedBasename.length);
+        // If the basename is in [allowed], don't count its "/." as making the
+        // file hidden.
+        var allowedBasename =
+            allowlistFilter.firstWhere(pathInDir.contains, orElse: () => null);
+        if (allowedBasename != null) {
+          pathInDir =
+              pathInDir.substring(0, pathInDir.length - allowedBasename.length);
         }
 
         if (pathInDir.contains('/.')) return false;
@@ -239,7 +239,7 @@
 /// as well as files (defaults to `true`).
 ///
-/// [whiteList] is a list of hidden filenames to include even when
+/// [allowed] is a list of hidden filenames to include even when
 /// [includeHidden] is `false`.
 ///
diff --git a/lib/src/package.dart b/lib/src/package.dart
index 48e48b4..7d7a55b 100644
--- a/lib/src/package.dart
+++ b/lib/src/package.dart
@@ -189,13 +189,13 @@
   }
 
   /// The basenames of files that are included in [list] despite being hidden.
-  static const _whitelistedFiles = ['.htaccess'];
+  static const _allowedFiles = ['.htaccess'];
 
-  /// A set of patterns that match paths to blacklisted files.
-  static final _blacklistedFiles = createFileFilter(['pubspec.lock']);
+  /// A set of patterns that match paths to disallowed files.
+  static final _disallowedFiles = createFileFilter(['pubspec.lock']);
 
-  /// A set of patterns that match paths to blacklisted directories.
-  static final _blacklistedDirs = createDirectoryFilter(['packages']);
+  /// A set of patterns that match paths to disallowed directories.
+  static final _disallowedDirs = createDirectoryFilter(['packages']);
 
   /// Returns a list of files that are considered to be part of this package.
   ///
@@ -264,9 +264,7 @@
       });
     } else {
       files = listDir(beneath,
-          recursive: recursive,
-          includeDirs: false,
-          whitelist: _whitelistedFiles);
+          recursive: recursive, includeDirs: false, allowed: _allowedFiles);
     }
 
     return files.where((file) {
@@ -282,8 +280,8 @@
       // contains() on, the leading separator is harmless.
       assert(file.startsWith(beneath));
       file = file.substring(beneath.length);
-      return !_blacklistedFiles.any(file.endsWith) &&
-          !_blacklistedDirs.any(file.contains);
+      return !_disallowedFiles.any(file.endsWith) &&
+          !_disallowedDirs.any(file.contains);
     }).toList();
   }
 
@@ -309,7 +307,7 @@
       // If the link points outside this repo, just use the default listing
       // logic.
       targetFiles = listDir(target,
-          recursive: true, includeDirs: false, whitelist: _whitelistedFiles);
+          recursive: true, includeDirs: false, allowed: _allowedFiles);
     }
 
     // Re-write the paths so they're underneath the symlink.